Class: Google::Cloud::Memorystore::V1beta::GetTokenAuthUserRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1beta/memorystore.rb

Overview

Request message for GetTokenAuthUser.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of token auth user for a basic auth enabled instance. Format: projects/{project}/locations/{location}/instances/{instance}/tokenAuthUsers/{token_auth_user}.

Returns:

  • (::String)

    Required. The name of token auth user for a basic auth enabled instance. Format: projects/{project}/locations/{location}/instances/{instance}/tokenAuthUsers/{token_auth_user}



1527
1528
1529
1530
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 1527

class GetTokenAuthUserRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end