Class: Google::Cloud::Memorystore::V1beta::Instance::StateInfo::UpdateInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1beta/memorystore.rb

Overview

Represents information about instance with state UPDATING.

Instance Attribute Summary collapse

Instance Attribute Details

#target_replica_count::Integer (readonly)

Returns Output only. Target number of replica nodes per shard for the instance.

Returns:

  • (::Integer)

    Output only. Target number of replica nodes per shard for the instance.



126
127
128
129
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 126

class UpdateInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_shard_count::Integer (readonly)

Returns Output only. Target number of shards for the instance.

Returns:

  • (::Integer)

    Output only. Target number of shards for the instance.



126
127
128
129
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 126

class UpdateInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end