Class: Google::Cloud::Memorystore::V1beta::ListTokenAuthUsersResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Memorystore::V1beta::ListTokenAuthUsersResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/memorystore/v1beta/memorystore.rb
Overview
Response message for ListTokenAuthUsers.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#token_auth_users ⇒ ::Array<::Google::Cloud::Memorystore::V1beta::TokenAuthUser>
A list of token auth users in the project.
-
#unreachable ⇒ ::Array<::String>
Unordered list.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns Token to retrieve the next page of results, or empty if there are no more results in the list.
1516 1517 1518 1519 |
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 1516 class ListTokenAuthUsersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#token_auth_users ⇒ ::Array<::Google::Cloud::Memorystore::V1beta::TokenAuthUser>
Returns A list of token auth users in the project.
1516 1517 1518 1519 |
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 1516 class ListTokenAuthUsersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unordered list. Token auth users that could not be reached.
1516 1517 1518 1519 |
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 1516 class ListTokenAuthUsersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |