Class: Google::Cloud::Memorystore::V1beta::PersistenceConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1beta/memorystore.rb

Overview

Represents persistence configuration for a instance.

Defined Under Namespace

Modules: PersistenceMode Classes: AOFConfig, RDBConfig

Instance Attribute Summary collapse

Instance Attribute Details

#aof_config::Google::Cloud::Memorystore::V1beta::PersistenceConfig::AOFConfig

Returns Optional. AOF configuration. This field will be ignored if mode is not AOF.

Returns:



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 412

class PersistenceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for RDB based persistence.
  # @!attribute [rw] rdb_snapshot_period
  #   @return [::Google::Cloud::Memorystore::V1beta::PersistenceConfig::RDBConfig::SnapshotPeriod]
  #     Optional. Period between RDB snapshots.
  # @!attribute [rw] rdb_snapshot_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. Time that the first snapshot was/will be attempted, and to
  #     which future snapshots will be aligned. If not provided, the current time
  #     will be used.
  class RDBConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Possible snapshot periods.
    module SnapshotPeriod
      # Not set.
      SNAPSHOT_PERIOD_UNSPECIFIED = 0

      # One hour.
      ONE_HOUR = 1

      # Six hours.
      SIX_HOURS = 2

      # Twelve hours.
      TWELVE_HOURS = 3

      # Twenty four hours.
      TWENTY_FOUR_HOURS = 4
    end
  end

  # Configuration for AOF based persistence.
  # @!attribute [rw] append_fsync
  #   @return [::Google::Cloud::Memorystore::V1beta::PersistenceConfig::AOFConfig::AppendFsync]
  #     Optional. The fsync mode.
  class AOFConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Possible fsync modes.
    module AppendFsync
      # Not set. Default: EVERY_SEC
      APPEND_FSYNC_UNSPECIFIED = 0

      # Never fsync. Normally Linux will flush data every 30 seconds with this
      # configuration, but it's up to the kernel's exact tuning.
      NEVER = 1

      # Fsync every second. You may lose 1 second of data if there is a
      # disaster.
      EVERY_SEC = 2

      # Fsync every time new write commands are appended to the AOF. The best
      # data loss protection at the cost of performance.
      ALWAYS = 3
    end
  end

  # Possible persistence modes.
  module PersistenceMode
    # Not set.
    PERSISTENCE_MODE_UNSPECIFIED = 0

    # Persistence is disabled, and any snapshot data is deleted.
    DISABLED = 1

    # RDB based persistence is enabled.
    RDB = 2

    # AOF based persistence is enabled.
    AOF = 3
  end
end

#mode::Google::Cloud::Memorystore::V1beta::PersistenceConfig::PersistenceMode

Returns Optional. Current persistence mode.

Returns:



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 412

class PersistenceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for RDB based persistence.
  # @!attribute [rw] rdb_snapshot_period
  #   @return [::Google::Cloud::Memorystore::V1beta::PersistenceConfig::RDBConfig::SnapshotPeriod]
  #     Optional. Period between RDB snapshots.
  # @!attribute [rw] rdb_snapshot_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. Time that the first snapshot was/will be attempted, and to
  #     which future snapshots will be aligned. If not provided, the current time
  #     will be used.
  class RDBConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Possible snapshot periods.
    module SnapshotPeriod
      # Not set.
      SNAPSHOT_PERIOD_UNSPECIFIED = 0

      # One hour.
      ONE_HOUR = 1

      # Six hours.
      SIX_HOURS = 2

      # Twelve hours.
      TWELVE_HOURS = 3

      # Twenty four hours.
      TWENTY_FOUR_HOURS = 4
    end
  end

  # Configuration for AOF based persistence.
  # @!attribute [rw] append_fsync
  #   @return [::Google::Cloud::Memorystore::V1beta::PersistenceConfig::AOFConfig::AppendFsync]
  #     Optional. The fsync mode.
  class AOFConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Possible fsync modes.
    module AppendFsync
      # Not set. Default: EVERY_SEC
      APPEND_FSYNC_UNSPECIFIED = 0

      # Never fsync. Normally Linux will flush data every 30 seconds with this
      # configuration, but it's up to the kernel's exact tuning.
      NEVER = 1

      # Fsync every second. You may lose 1 second of data if there is a
      # disaster.
      EVERY_SEC = 2

      # Fsync every time new write commands are appended to the AOF. The best
      # data loss protection at the cost of performance.
      ALWAYS = 3
    end
  end

  # Possible persistence modes.
  module PersistenceMode
    # Not set.
    PERSISTENCE_MODE_UNSPECIFIED = 0

    # Persistence is disabled, and any snapshot data is deleted.
    DISABLED = 1

    # RDB based persistence is enabled.
    RDB = 2

    # AOF based persistence is enabled.
    AOF = 3
  end
end

#rdb_config::Google::Cloud::Memorystore::V1beta::PersistenceConfig::RDBConfig

Returns Optional. RDB configuration. This field will be ignored if mode is not RDB.

Returns:



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 412

class PersistenceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for RDB based persistence.
  # @!attribute [rw] rdb_snapshot_period
  #   @return [::Google::Cloud::Memorystore::V1beta::PersistenceConfig::RDBConfig::SnapshotPeriod]
  #     Optional. Period between RDB snapshots.
  # @!attribute [rw] rdb_snapshot_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. Time that the first snapshot was/will be attempted, and to
  #     which future snapshots will be aligned. If not provided, the current time
  #     will be used.
  class RDBConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Possible snapshot periods.
    module SnapshotPeriod
      # Not set.
      SNAPSHOT_PERIOD_UNSPECIFIED = 0

      # One hour.
      ONE_HOUR = 1

      # Six hours.
      SIX_HOURS = 2

      # Twelve hours.
      TWELVE_HOURS = 3

      # Twenty four hours.
      TWENTY_FOUR_HOURS = 4
    end
  end

  # Configuration for AOF based persistence.
  # @!attribute [rw] append_fsync
  #   @return [::Google::Cloud::Memorystore::V1beta::PersistenceConfig::AOFConfig::AppendFsync]
  #     Optional. The fsync mode.
  class AOFConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Possible fsync modes.
    module AppendFsync
      # Not set. Default: EVERY_SEC
      APPEND_FSYNC_UNSPECIFIED = 0

      # Never fsync. Normally Linux will flush data every 30 seconds with this
      # configuration, but it's up to the kernel's exact tuning.
      NEVER = 1

      # Fsync every second. You may lose 1 second of data if there is a
      # disaster.
      EVERY_SEC = 2

      # Fsync every time new write commands are appended to the AOF. The best
      # data loss protection at the cost of performance.
      ALWAYS = 3
    end
  end

  # Possible persistence modes.
  module PersistenceMode
    # Not set.
    PERSISTENCE_MODE_UNSPECIFIED = 0

    # Persistence is disabled, and any snapshot data is deleted.
    DISABLED = 1

    # RDB based persistence is enabled.
    RDB = 2

    # AOF based persistence is enabled.
    AOF = 3
  end
end