Class: Google::Cloud::Memorystore::V1beta::PersistenceConfig::RDBConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1beta/memorystore.rb

Overview

Configuration for RDB based persistence.

Defined Under Namespace

Modules: SnapshotPeriod

Instance Attribute Summary collapse

Instance Attribute Details

#rdb_snapshot_period::Google::Cloud::Memorystore::V1beta::PersistenceConfig::RDBConfig::SnapshotPeriod

Returns Optional. Period between RDB snapshots.

Returns:



425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 425

class RDBConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible snapshot periods.
  module SnapshotPeriod
    # Not set.
    SNAPSHOT_PERIOD_UNSPECIFIED = 0

    # One hour.
    ONE_HOUR = 1

    # Six hours.
    SIX_HOURS = 2

    # Twelve hours.
    TWELVE_HOURS = 3

    # Twenty four hours.
    TWENTY_FOUR_HOURS = 4
  end
end

#rdb_snapshot_start_time::Google::Protobuf::Timestamp

Returns Optional. Time that the first snapshot was/will be attempted, and to which future snapshots will be aligned. If not provided, the current time will be used.

Returns:

  • (::Google::Protobuf::Timestamp)

    Optional. Time that the first snapshot was/will be attempted, and to which future snapshots will be aligned. If not provided, the current time will be used.



425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 425

class RDBConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible snapshot periods.
  module SnapshotPeriod
    # Not set.
    SNAPSHOT_PERIOD_UNSPECIFIED = 0

    # One hour.
    ONE_HOUR = 1

    # Six hours.
    SIX_HOURS = 2

    # Twelve hours.
    TWELVE_HOURS = 3

    # Twenty four hours.
    TWENTY_FOUR_HOURS = 4
  end
end