Class: Google::Cloud::Memorystore::V1beta::PscAutoConnection

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1beta/memorystore.rb

Overview

Details of consumer resources in a PSC connection.

Instance Attribute Summary collapse

Instance Attribute Details

#connection_type::Google::Cloud::Memorystore::V1beta::ConnectionType (readonly)

Returns Output only. Type of the PSC connection.

Returns:



339
340
341
342
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 339

class PscAutoConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#forwarding_rule::String (readonly)

Returns Output only. The URI of the consumer side forwarding rule. Format: projects/{project}/regions/{region}/forwardingRules/{forwarding_rule}.

Returns:

  • (::String)

    Output only. The URI of the consumer side forwarding rule. Format: projects/{project}/regions/{region}/forwardingRules/{forwarding_rule}



339
340
341
342
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 339

class PscAutoConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ip_address::String (readonly)

Returns Output only. The IP allocated on the consumer network for the PSC forwarding rule.

Returns:

  • (::String)

    Output only. The IP allocated on the consumer network for the PSC forwarding rule.



339
340
341
342
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 339

class PscAutoConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#network::String

Returns Required. The network where the PSC endpoints are created, in the form of projects/{project_id}/global/networks/{network_id}.

Returns:

  • (::String)

    Required. The network where the PSC endpoints are created, in the form of projects/{project_id}/global/networks/{network_id}.



339
340
341
342
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 339

class PscAutoConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#port::Integer (readonly)

Returns Optional. Output only. port will only be set for Primary/Reader or Discovery endpoint.

Returns:

  • (::Integer)

    Optional. Output only. port will only be set for Primary/Reader or Discovery endpoint.



339
340
341
342
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 339

class PscAutoConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project_id::String

Returns Required. The consumer project_id where PSC connections are established. This should be the same project_id that the instance is being created in.

Returns:

  • (::String)

    Required. The consumer project_id where PSC connections are established. This should be the same project_id that the instance is being created in.



339
340
341
342
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 339

class PscAutoConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#psc_connection_id::String (readonly)

Returns Output only. The PSC connection id of the forwarding rule connected to the service attachment.

Returns:

  • (::String)

    Output only. The PSC connection id of the forwarding rule connected to the service attachment.



339
340
341
342
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 339

class PscAutoConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#psc_connection_status::Google::Cloud::Memorystore::V1beta::PscConnectionStatus (readonly)

Returns Output only. The status of the PSC connection: whether a connection exists and ACTIVE or it no longer exists. Please note that this value is updated periodically. Please use Private Service Connect APIs for the latest status.

Returns:

  • (::Google::Cloud::Memorystore::V1beta::PscConnectionStatus)

    Output only. The status of the PSC connection: whether a connection exists and ACTIVE or it no longer exists. Please note that this value is updated periodically. Please use Private Service Connect APIs for the latest status.



339
340
341
342
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 339

class PscAutoConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#service_attachment::String (readonly)

Returns Output only. The service attachment which is the target of the PSC connection, in the form of projects/{project-id}/regions/{region}/serviceAttachments/{service-attachment-id}.

Returns:

  • (::String)

    Output only. The service attachment which is the target of the PSC connection, in the form of projects/{project-id}/regions/{region}/serviceAttachments/{service-attachment-id}.



339
340
341
342
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 339

class PscAutoConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end