Class: Google::Cloud::Memorystore::V1beta::PscConnection

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1beta/memorystore.rb

Overview

User created Psc connection configuration.

Instance Attribute Summary collapse

Instance Attribute Details

#connection_type::Google::Cloud::Memorystore::V1beta::ConnectionType (readonly)

Returns Output only. Type of the PSC connection.

Returns:



380
381
382
383
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 380

class PscConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#forwarding_rule::String

Returns Required. The URI of the consumer side forwarding rule. Format: projects/{project}/regions/{region}/forwardingRules/{forwarding_rule}.

Returns:

  • (::String)

    Required. The URI of the consumer side forwarding rule. Format: projects/{project}/regions/{region}/forwardingRules/{forwarding_rule}



380
381
382
383
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 380

class PscConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ip_address::String

Returns Required. The IP allocated on the consumer network for the PSC forwarding rule.

Returns:

  • (::String)

    Required. The IP allocated on the consumer network for the PSC forwarding rule.



380
381
382
383
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 380

class PscConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#network::String

Returns Required. The consumer network where the IP address resides, in the form of projects/{project_id}/global/networks/{network_id}.

Returns:

  • (::String)

    Required. The consumer network where the IP address resides, in the form of projects/{project_id}/global/networks/{network_id}.



380
381
382
383
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 380

class PscConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project_id::String (readonly)

Returns Output only. The consumer project_id where the forwarding rule is created from.

Returns:

  • (::String)

    Output only. The consumer project_id where the forwarding rule is created from.



380
381
382
383
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 380

class PscConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#psc_connection_id::String (readonly)

Returns Output only. The PSC connection id of the forwarding rule connected to the service attachment.

Returns:

  • (::String)

    Output only. The PSC connection id of the forwarding rule connected to the service attachment.



380
381
382
383
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 380

class PscConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#psc_connection_status::Google::Cloud::Memorystore::V1beta::PscConnectionStatus (readonly)

Returns Output only. The status of the PSC connection: whether a connection exists and ACTIVE or it no longer exists. Please note that this value is updated periodically. Please use Private Service Connect APIs for the latest status.

Returns:

  • (::Google::Cloud::Memorystore::V1beta::PscConnectionStatus)

    Output only. The status of the PSC connection: whether a connection exists and ACTIVE or it no longer exists. Please note that this value is updated periodically. Please use Private Service Connect APIs for the latest status.



380
381
382
383
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 380

class PscConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#service_attachment::String

Returns Required. The service attachment which is the target of the PSC connection, in the form of projects/{project-id}/regions/{region}/serviceAttachments/{service-attachment-id}.

Returns:

  • (::String)

    Required. The service attachment which is the target of the PSC connection, in the form of projects/{project-id}/regions/{region}/serviceAttachments/{service-attachment-id}.



380
381
382
383
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 380

class PscConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end