Class: Google::Cloud::Memorystore::V1beta::SharedRegionalCertificateAuthority

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1beta/memorystore.rb

Overview

Shared regional certificate authority for an instance.

Defined Under Namespace

Classes: RegionalManagedCertificateAuthority

Instance Attribute Summary collapse

Instance Attribute Details

#managed_server_ca::Google::Cloud::Memorystore::V1beta::SharedRegionalCertificateAuthority::RegionalManagedCertificateAuthority

Returns CA certificate chains for memorystore managed server authentication.

Returns:



723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 723

class SharedRegionalCertificateAuthority
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CA certificate chains for memorystore managed server authentication.
  # @!attribute [rw] ca_certs
  #   @return [::Array<::Google::Cloud::Memorystore::V1beta::SharedRegionalCertificateAuthority::RegionalManagedCertificateAuthority::RegionalCertChain>]
  #     The PEM encoded CA certificate chains for memorystore managed
  #     server authentication
  class RegionalManagedCertificateAuthority
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The certificates that form the CA chain, from leaf to root order.
    # @!attribute [rw] certificates
    #   @return [::Array<::String>]
    #     The certificates that form the CA chain, from leaf to root order.
    class RegionalCertChain
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#name::String

Returns Identifier. Unique name of the resource in this scope including project and location using the form: projects/{project}/locations/{location}/sharedRegionalCertificateAuthority.

Returns:

  • (::String)

    Identifier. Unique name of the resource in this scope including project and location using the form: projects/{project}/locations/{location}/sharedRegionalCertificateAuthority



723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 723

class SharedRegionalCertificateAuthority
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CA certificate chains for memorystore managed server authentication.
  # @!attribute [rw] ca_certs
  #   @return [::Array<::Google::Cloud::Memorystore::V1beta::SharedRegionalCertificateAuthority::RegionalManagedCertificateAuthority::RegionalCertChain>]
  #     The PEM encoded CA certificate chains for memorystore managed
  #     server authentication
  class RegionalManagedCertificateAuthority
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The certificates that form the CA chain, from leaf to root order.
    # @!attribute [rw] certificates
    #   @return [::Array<::String>]
    #     The certificates that form the CA chain, from leaf to root order.
    class RegionalCertChain
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end