Class: Google::Cloud::Memorystore::V1beta::TokenAuthUser

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memorystore/v1beta/memorystore.rb

Overview

Token based auth user for the instance.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Identifier. Token based auth user name.

Returns:

  • (::String)

    Identifier. Token based auth user name.



792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 792

class TokenAuthUser
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the different states of a token based auth user.
  # New values may be added in the future.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The auth user is active.
    ACTIVE = 1

    # The auth user is being created.
    CREATING = 2

    # The auth user is being updated.
    UPDATING = 3

    # The auth user is being deleted.
    DELETING = 4
  end
end

#state::Google::Cloud::Memorystore::V1beta::TokenAuthUser::State (readonly)

Returns Output only. The state of the token based auth user.

Returns:



792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
# File 'proto_docs/google/cloud/memorystore/v1beta/memorystore.rb', line 792

class TokenAuthUser
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the different states of a token based auth user.
  # New values may be added in the future.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The auth user is active.
    ACTIVE = 1

    # The auth user is being created.
    CREATING = 2

    # The auth user is being updated.
    UPDATING = 3

    # The auth user is being deleted.
    DELETING = 4
  end
end